#!/usr/bin/env bash
# ------------------------------------------------------------------------------
# This file builds the ecTrans dwarf.
# ------------------------------------------------------------------------------

# Load helpers for color printing.
source helpers.sh

# Setup required modules.
source load_modules.sh

# Set compilers for make/cmake.
export FC90=ftn
export FC=ftn
export CC=cc
export CXX=CC

# Load directory structure for installation paths.
source dirs.sh

# Export environment variables used during installation.
export PATH=${PATH}:${INSTALLDIR}/ecbuild/bin/
export PATH=${PATH}:${INSTALLDIR}/ecbuild/bin/
export TOOLCHAIN_FILE=${SOURCEDIR}/ectrans/toolchain_lumi.cmake
export ECBUILD_TOOLCHAIN="${TOOLCHAIN_FILE}"

# Create directories for the build process.
mkdir -p "${BASEDIR}" "${SOURCEDIR}" "${BUILDDIR}" "${INSTALLDIR}"

# Pull ecTrans for the toolchain config, but build as last.
info "==> PULLING ECTRANS"
cd ${SOURCEDIR}
git clone --branch alaro_ectrans https://github.com/ddegrauwe/ectrans.git
cd ectrans
success "==> SUCCESFULLY PULLED ECTRANS"

# Clonse and Install ecBuild.
info "==> INSTALLING ECBUILD.."
cd ${SOURCEDIR}
# Clone specific tag.
git clone --branch "3.8.2" https://github.com/ecmwf/ecbuild.git
cd ecbuild
# Remove obsolete switch '-Gfast'.
sed -i -e "s/-Gfast//" cmake/compiler_flags/Cray_Fortran.cmake
mkdir -p ${BUILDDIR}/ecbuild
cd ${BUILDDIR}/ecbuild
info "==>\t ECBUILD.."
${SOURCEDIR}/ecbuild/bin/ecbuild --prefix=${INSTALLDIR}/ecbuild ${SOURCEDIR}/ecbuild
info "==>\t MAKE.."
make
info "==>\t MAKE INSTALL.."
make install
success "==> SUCCESFULLY INSTALLED ECBUILD"

# Clone and Install FIAT.
info "==> INSTALLING FIAT.."
cd ${SOURCEDIR}
# Clone specific tag.
git clone --branch "1.2.0" https://github.com/ecmwf-ifs/fiat
cd fiat
# small fix to include OpenMP in linking of C programs
sed -i -e "s/target_link_libraries( fiat-printbinding OpenMP::OpenMP_C )/target_link_libraries( fiat-printbinding \$\{OpenMP_C_FLAGS\} OpenMP::OpenMP_C )/" src/programs/CMakeLists.txt
rm -rf ${BUILDDIR}/${FIAT_DIR}
mkdir -p ${BUILDDIR}/${FIAT_DIR}
cd ${BUILDDIR}/${FIAT_DIR}
info "==>\t ECBUILD.."
ecbuild -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=${INSTALLDIR}/${FIAT_DIR} -DENABLE_MPI=ON -DBUILD_SHARED_LIBS=OFF -DENABLE_TESTS=OFF ${SOURCEDIR}/fiat
info "==>\t MAKE.."
make -j16
info "==>\t MAKE INSTALL.."
make install
success "==> SUCCESFULLY INSTALLED FIAT"

# Clone and Install ecTrans.
info "==> Installing ecTrans.."
rm -rf ${BUILDDIR}/${ECTRANS_DIR} ${INSTALLDIR}/${ECTRANS_DIR}
mkdir -p ${BUILDDIR}/${ECTRANS_DIR}
cd ${BUILDDIR}/${ECTRANS_DIR}
info "==>\t ECBUILD.."
ecbuild --prefix=${INSTALLDIR}/${ECTRANS_DIR} -DCMAKE_BUILD_TYPE=RelWithDebInfo -Dfiat_ROOT=${INSTALLDIR}/${FIAT_DIR} -DBUILD_SHARED_LIBS=OFF -DENABLE_FFTW=OFF -DENABLE_GPU=ON -DENABLE_OMPGPU=OFF -DENABLE_ACCGPU=ON -DENABLE_TESTS=OFF -DENABLE_GPU_AWARE_MPI=ON -DENABLE_CPU=ON -DENABLE_ETRANS=ON  -DENABLE_DOUBLE_PRECISION=ON -DENABLE_SINGLE_PRECISION=OFF ${SOURCEDIR}/ectrans
info "==>\t MAKE (supposed to fail).."
make -j32
# Make needs to be executed twice as the first time it somehow fails.
info "==>\t MAKE (again, should succeed).."
make -j32
info "==>\t MAKE INSTALL.."
make install
success "==> SUCCESFULLY INSTALLED ECTRANS"
