#!/usr/bin/env bash
# ------------------------------------------------------------------------------
# This file runs the ecTrans dwarf within a submitted job.
# ------------------------------------------------------------------------------
#SBATCH --job-name=ectrans_sbatch
#SBATCH --partition=small-g
#SBATCH --exclusive
#SBATCH --mem=0
#SBATCH --account=project_465000454
#SBATCH --nodes=1
#SBATCH --gpus-per-node=8
#SBATCH --ntasks=8
#SBATCH --time=4:00:00

# Load directory structure of installation.
source dirs.sh

# Set runtime arguments to ENV value or default.
[ -z "$TRUNCATION" ] && TRUNCATION=79
[ -z "$NPROMA" ] && NPROMA=32
[ -z "$NFLD"] && NFLD=1
[ -z "$NLEV" ] && NLEV=10
[ -z "$CHECK" ] && CHECK=10

# Create "select_gpu" script as indicated by Lumi documentation.
SELECT_GPU_NAME=./select_gpu_sbatch
rm -rf "$SELECT_GPU_NAME"
cat << EOF > "$SELECT_GPU_NAME"
#!/bin/bash

export ROCR_VISIBLE_DEVICES=\$SLURM_LOCALID
exec \$*
EOF
chmod +x "$SELECT_GPU_NAME"

# Setup runtime config.
export MPICH_GPU_SUPPORT_ENABLED=1
CPU_BIND="map_cpu:48,56,16,24,1,8,32,40"

# Run ecTrans with given arguments.
ARGS="--truncation $TRUNCATION --nproma $NPROMA --vordiv --scders --uvders
        --nfld $NFLD --nlev $NLEV --norms --check $CHECK"
srun --cpu-bind=${CPU_BIND} "$SELECT_GPU_NAME" \
        ${INSTALLDIR}/${ECTRANS_DIR}/bin/ectrans-lam-benchmark-dp ${ARGS}

# Delete the "select_gpu_sbatch" script.
rm -rf "$SELECT_GPU_NAME"
